dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.distances module — dtw_loss_functions documentation

# dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.distances module

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.distances.pairwise_distance(x: Tensor, y: Tensor, *, dist: str) → Tensor

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.distances.sqeuclidean(x: Tensor, y: Tensor) → Tensor
  Efficient squared Euclidean distance:

    D[b,i,j] = ||x[b,i]-y[b,j]||^2

  x: (B,N,D), y: (B,M,D) returns: (B,N,M)